package com.retailstore.ordermanagement.application;

import com.retailstore.ordermanagement.service.RetailStoreService;
import com.retailstore.ordermanagement.service.RetailStoreServiceImpl;
import com.retailstore.ordermanagement.utils.DBUtil;
import lombok.extern.java.Log;

import java.sql.SQLException;
import java.util.Scanner;

import static com.retailstore.ordermanagement.utils.InputUtil.validateInputNumber;

/**
 * The project run starts from here
 */
@Log
public class OrderManagement {
    private Scanner scanner;

    /**
     * No-Arg Constructor for class OrderManagement with their private
     * instance variables
     */
    public OrderManagement() {
        System.setProperty("java.util.logging.SimpleFormatter.format",
                "%5$s %n");
        this.scanner = new Scanner(System.in);
    }

    /**
     * Method menu where it shows there regular options to go particular
     * functionality regarding the selected option in the console.
     */
    public void menu() {
        String option1 = "1. Add product to your stock";
        String option2 = "2. Order Product";
        String option3 = "3. Get order details";
        String option4 = "4. Exit";
        String toExit = "To exit please enter 4";
        String toAddMore = "To Add more enter 1";
        String enterForMenu = "Please enter 5 for menu";

        boolean flag = true;
        log.info("Welcome to RetailStore Business Management");
        RetailStoreService gap = new RetailStoreServiceImpl();
        String menu = "\n------------------------\nMenu\n------------------------\n" +
                option1 + "\n------------------------\n" +
                option2 + "\n------------------------\n" +
                option3 + "\n------------------------\n" +
                option4;
        log.info(menu);
        while (flag) {
            int menuOption;
            menuOption = validateInputNumber();
            switch (menuOption) {
                case 1:
                    gap.addProducts();
                    log.info("\n------------------------\n" + enterForMenu + "\n------------------------\n" +
                            toExit + "\n------------------------\n" +
                            toAddMore + "\n------------------------\n");
                    break;
                case 2:
                    gap.placeOrders();
                    log.info("\n------------------------\n" + enterForMenu + "\n------------------------\n" +
                            toExit);
                    break;
                case 3:
                    gap.showOrders();
                    log.info("\n------------------------\n" + enterForMenu + "\n------------------------\n" +
                            toExit);
                    break;
                case 4:
                    log.info("Good Bye.");
                    flag = false;
                    try {
                        DBUtil.getConnection().close();
                    } catch (SQLException e) {
                        log.warning(e.getMessage());
                    }
                    break;
                case 5:
                    log.info(menu);
                    break;
                default:
                    log.warning("\n------------------------\nPlease enter valid menu option\n------------------------\n");
                    log.info(menu);
            }
        }
    }

    /**
     * Main method where this application execution starts
     *
     * @param args
     */
    public static void main(String[] args) {
        OrderManagement orderManagement = new OrderManagement();
        orderManagement.menu();
    }
}
