package com.retailstore.ordermanagement.model;


import com.retailstore.ordermanagement.constants.Category;
import com.retailstore.ordermanagement.constants.Color;
import com.retailstore.ordermanagement.constants.Gender;
import com.retailstore.ordermanagement.constants.Size;
import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Map;

/**
 * CLass product
 * ...In this all the variables and methods are
 * used to create the product list as required per the admin
 */
@Getter
@AllArgsConstructor
public class Product {
    private String id;
    private String name;
    private Category category;
    private Color color;
    private double price;
    private Gender idealFor;
    private Map<Size, Integer> size;

    /**
     * This method is used to get all the available sizes in the product list
     * of in the string format
     *
     * @return
     */
    public String getProductSizeAvailability() {
        return size.entrySet().stream().map(entry -> entry.getKey() + " - " + entry.getValue()).reduce("", (sizes, size) -> sizes + "\n" + size.toString());
    }

    /**
     * This method is used to get the boolean value according to
     * the availability of the stock in products table
     *
     * @return boolean -> true,false
     */
    public boolean outOfStock() {
        return size.entrySet().stream().allMatch(entry -> entry.getValue() <= 0);
    }

    /**
     * This method is used to get the whether the sizes are out of stock or
     * present in the database if present the sizes are shown
     *
     * @return string
     */
    public String showSizes() {
        return outOfStock() ? "* Out of Stock *" : "Sizes available : " + size.entrySet().stream().map(size -> size.getKey() + "-" + size.getValue()).reduce((sizes, size) -> sizes + ", " + size).get();
    }

    /**
     * This method is used to get the menu of the product according to the required
     * variables which are used above
     *
     * @return string
     */
    public String productShowcaseInMenu() {
        return getName() + "\t" + getPrice() + "\n   " + getColor() + "\t" + showSizes();
    }

    /**
     * This is method to give the product values in string format
     *
     * @return string
     */
    @Override
    public String toString() {
        return "Product{" +
                "id='" + id + '\'' +
                ", name='" + name + '\'' +
                ", category=" + category +
                ", color=" + color +
                ", price=" + price +
                ", idealFor=" + idealFor +
                ", size=" + getProductSizeAvailability() +
                '}';
    }
}