package com.retailstore.ordermanagement.service;

import com.retailstore.ordermanagement.constants.Category;
import com.retailstore.ordermanagement.constants.Color;
import com.retailstore.ordermanagement.constants.Gender;
import com.retailstore.ordermanagement.model.Order;
import com.retailstore.ordermanagement.model.Product;

import java.sql.Connection;
import java.util.Map;

/**
 * interface ProductFilter
 * This is an interface to filter the products according to
 * respective of taken methods in this interface
 */
public interface ProductService {
    /**
     * This is an abstract method gives the
     * categories of product according selection of gender type
     *
     * @param gender
     * @return category according key value of type integer
     */
    public Map<Integer, Category> getCategoriesByGender(Gender gender);

    /**
     * This abstract method is used to get the all orders present
     *
     * @param connection
     * @return order according to key value of type integer
     */
    public Map<Integer, Order> getOrders(Connection connection);

    /**
     * This abstract method is used to get the colors present to the products which
     * are filter according to the Gender and Category
     *
     * @param gender
     * @param category
     * @return color according to key value of type integer
     */
    public Map<Integer, Color> getColorsByGenderAndCategory(Gender gender, Category category);

    /**
     * This abstract method gives all the products which are
     * filtered by the gender and category
     *
     * @param gender
     * @param category
     * @return product according to key value of type integer
     */
    public Map<Integer, Product> getProductsByGenderAndCategory(Gender gender, Category category);

}
