package com.retailstore.ordermanagement.service;

import com.retailstore.ordermanagement.constants.Category;
import com.retailstore.ordermanagement.constants.Color;
import com.retailstore.ordermanagement.constants.Gender;
import com.retailstore.ordermanagement.model.Order;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.Mock;

import java.sql.Connection;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.ArrayList;
import java.util.Map;
import java.util.stream.Collectors;

class ProductServiceTest {
    @Mock
    Connection connection;
    RetailStoreServiceImpl service;

    @BeforeEach
    void createretailsStoreObject() {
        service = new RetailStoreServiceImpl();
    }

    @AfterEach
    void removeretailsStoreObject() {
        service = null;
    }

    @Test
    void getCategoriesByGenderTest() {
        Map<Integer, Category> categoryMap = new LinkedHashMap<>();
        categoryMap.put(1, Category.SWEATSHIRTS);
        categoryMap.put(2, Category.T_SHIRTS);
        categoryMap.put(3, Category.SHIRTS);
        categoryMap.put(4, Category.SHORTS);
        categoryMap.put(5, Category.HOODIES);
        categoryMap.put(6, Category.PANTS);
        categoryMap.put(7, Category.JEANS);
        categoryMap.put(8, Category.POLOS);
        Assertions.assertEquals(categoryMap, service.getCategoriesByGender(Gender.MEN));
    }

    @Test
    void getProductsByGenderAndCategoryTest() {
        List<String> productsList = new ArrayList<>();
        productsList.add("14e0#Gap");
        productsList.add("86f0#Gap");
        productsList.add("9064#Gap");
        productsList.add("b715#Gap");
        Assertions.assertEquals(productsList, service.getProductsByGenderAndCategory(Gender.MEN, Category.HOODIES).entrySet().stream().map(product -> product.getValue().getId()).collect(Collectors.toList()));
        productsList.clear();
        Assertions.assertEquals(productsList, service.getProductsByGenderAndCategory(Gender.WOMEN, Category.PANTS).entrySet().stream().map(product -> product.getValue().getId()).collect(Collectors.toList()));
    }

    @Test
    void getColorsByGenderAndCategoryTest() {
        Map<Integer, Color> colorMap = new LinkedHashMap<>();
        colorMap.put(1, Color.BLUE);
        colorMap.put(2, Color.GREY);
        colorMap.put(3, Color.BLACK);
        Assertions.assertEquals(colorMap, service.getColorsByGenderAndCategory(Gender.MEN, Category.JEANS));
        colorMap.clear();
        Assertions.assertEquals(colorMap, service.getColorsByGenderAndCategory(Gender.MEN, Category.DRESS));
    }

    @Test
    void getOrdersTest() {
        List<Order> orderList = new ArrayList<>();
        Map<Integer, Order> ordersMap = new LinkedHashMap<>();
        Assertions.assertEquals(ordersMap, service.getOrders(connection));
    }
}